@@ -4,6 +4,9 @@ from edc_constants.constants import CLOSED, OPEN
 
 
 class AeSusarMethodsModelMixin(models.Model):
+    class Meta:
+        abstract = True
+
     def __str__(self):
         return f"{self.action_identifier[-9:]}"
 
@@ -18,7 +21,4 @@ class AeSusarMethodsModelMixin(models.Model):
         super().save(*args, **kwargs)
 
     def natural_key(self):
-        return (self.action_identifier,)  # noqa
-
-    class Meta:
-        abstract = True
+        return (self.action_identifier,)
