@@ -4,7 +4,7 @@ import calendar
 import sys
 import warnings
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, Type
+from typing import TYPE_CHECKING, Any
 
 from dateutil.relativedelta import relativedelta
 from django.apps import apps as django_apps
@@ -23,9 +23,8 @@ from django.db.models import Count, ProtectedError
 from django.urls import reverse
 from django.utils.translation import gettext as _
 
-from edc_constants.constants import CLINIC
+from edc_constants.constants import CLINIC, NOT_APPLICABLE, OK
 from edc_constants.constants import ERROR as ERROR_CODE
-from edc_constants.constants import NOT_APPLICABLE, OK
 from edc_dashboard.url_names import url_names
 from edc_form_validators import INVALID_ERROR
 from edc_metadata.constants import CRF, REQUIRED, REQUISITION
@@ -81,7 +80,7 @@ class AppointmentDateWindowPeriodGapError(Exception):
     pass
 
 
-class AppointmentAlreadyStarted(Exception):
+class AppointmentAlreadyStarted(Exception):  # noqa: N818
     pass
 
 
@@ -89,7 +88,7 @@ def get_appointment_model_name() -> str:
     return "edc_appointment.appointment"
 
 
-def get_appointment_model_cls() -> Type[Appointment]:
+def get_appointment_model_cls() -> type[Appointment]:
     return django_apps.get_model(get_appointment_model_name())
 
 
@@ -97,7 +96,7 @@ def get_appointment_type_model_name() -> str:
     return "edc_appointment.appointmenttype"
 
 
-def get_appointment_type_model_cls() -> Type[AppointmentType]:
+def get_appointment_type_model_cls() -> type[AppointmentType]:
     return django_apps.get_model(get_appointment_type_model_name())
 
 
@@ -158,10 +157,9 @@ def raise_on_appt_may_not_be_missed(
 
 
 def get_appointment_form_meta_options() -> dict:
-    options = getattr(
+    return getattr(
         settings, "EDC_APPOINTMENT_FORM_META_OPTIONS", dict(labels={}, help_texts={})
     )
-    return options
 
 
 def get_appt_reason_choices() -> tuple[str, ...]:
@@ -291,9 +289,7 @@ def reset_visit_code_sequence_or_pass(
                 f"{subject_identifier} {visit_code}: {actual=} {expected=} ...\n"
             )
         # reset visit code sequence for this visit code
-        get_crf_metadata_model_cls().objects.filter(
-            visit_code_sequence__gt=0, **opts
-        ).delete()
+        get_crf_metadata_model_cls().objects.filter(visit_code_sequence__gt=0, **opts).delete()
         get_requisition_metadata_model_cls().objects.filter(
             visit_code_sequence__gt=0, **opts
         ).delete()
@@ -309,9 +305,7 @@ def reset_visit_code_sequence_or_pass(
                     obj.save_base(update_fields=["visit_code_sequence"])
                     if getattr(obj, "related_visit", None):
                         obj.related_visit.visit_code_sequence = obj.visit_code_sequence
-                        obj.related_visit.save_base(
-                            update_fields=["visit_code_sequence"]
-                        )
+                        obj.related_visit.save_base(update_fields=["visit_code_sequence"])
                         obj.related_visit.metadata_create()
 
                 # reset sequence order by appt_datetime
@@ -325,9 +319,7 @@ def reset_visit_code_sequence_or_pass(
                     obj.save_base(update_fields=["visit_code_sequence"])
                     if getattr(obj, "related_visit", None):
                         obj.related_visit.visit_code_sequence = index
-                        obj.related_visit.save_base(
-                            update_fields=["visit_code_sequence"]
-                        )
+                        obj.related_visit.save_base(update_fields=["visit_code_sequence"])
                         obj.related_visit.metadata_create()
 
         except IntegrityError:
@@ -375,7 +367,6 @@ def delete_appointment_in_sequence(appointment: Any, from_post_delete=None) -> N
             schedule_name=appointment.schedule_name,
             visit_code=appointment.visit_code,
         )
-    return None
 
 
 def update_appt_status(appointment: Appointment, save: bool | None = None):
@@ -385,21 +376,17 @@ def update_appt_status(appointment: Appointment, save: bool | None = None):
     relative to the visit tracking model and CRFs and
     requisitions
     """
-    if (
-        appointment.appt_status == CANCELLED_APPT
-        or appointment.appt_status == SKIPPED_APPT
-    ):
+    if appointment.appt_status == CANCELLED_APPT or appointment.appt_status == SKIPPED_APPT:
         pass
     elif not appointment.related_visit:
         appointment.appt_status = NEW_APPT
+    elif (
+        appointment.crf_metadata_required_exists
+        or appointment.requisition_metadata_required_exists
+    ):
+        appointment.appt_status = INCOMPLETE_APPT
     else:
-        if (
-            appointment.crf_metadata_required_exists
-            or appointment.requisition_metadata_required_exists
-        ):
-            appointment.appt_status = INCOMPLETE_APPT
-        else:
-            appointment.appt_status = COMPLETE_APPT
+        appointment.appt_status = COMPLETE_APPT
     if save:
         appointment.save_base(update_fields=["appt_status"])
         appointment.refresh_from_db()
@@ -451,9 +438,7 @@ def get_previous_appointment(
     return previous_appt
 
 
-def get_next_appointment(
-    appointment: Appointment, include_interim=None
-) -> Appointment | None:
+def get_next_appointment(appointment: Appointment, include_interim=None) -> Appointment | None:
     """Returns the next appointment model instance,
     or None, in this schedule.
 
@@ -511,9 +496,7 @@ def raise_on_appt_datetime_not_in_window(
     appt_datetime: datetime | None = None,
     baseline_timepoint_datetime: datetime | None = None,
 ) -> None:
-    if appointment.appt_status != CANCELLED_APPT and not is_baseline(
-        instance=appointment
-    ):
+    if appointment.appt_status != CANCELLED_APPT and not is_baseline(instance=appointment):
         baseline_timepoint_datetime = baseline_timepoint_datetime or (
             appointment.__class__.objects.first_appointment(
                 subject_identifier=appointment.subject_identifier,
@@ -532,11 +515,11 @@ def raise_on_appt_datetime_not_in_window(
         except ScheduledVisitWindowError as e:
             msg = str(e)
             msg.replace("Invalid datetime", "Invalid appointment datetime (S)")
-            raise AppointmentWindowError(msg)
+            raise AppointmentWindowError(msg) from e
         except UnScheduledVisitWindowError as e:
             msg = str(e)
             msg.replace("Invalid datetime", "Invalid appointment datetime (U)")
-            raise AppointmentWindowError(msg)
+            raise AppointmentWindowError(msg) from e
 
 
 def get_window_gap_days(appointment) -> int:
@@ -555,9 +538,7 @@ def get_window_gap_days(appointment) -> int:
     return gap_days
 
 
-def appt_datetime_in_gap(
-    appointment: Appointment, suggested_appt_datetime: datetime
-) -> bool:
+def appt_datetime_in_gap(appointment: Appointment, suggested_appt_datetime: datetime) -> bool:
     """Return True if datetime falls in a gap between this and the
     next appointment window.
     """
@@ -575,8 +556,7 @@ def appt_datetime_in_gap(
 def get_max_window_gap_to_lower(appointment) -> int:
     if (
         appointment.visit.max_window_gap_to_lower is not None
-        and appointment.visit.max_window_gap_to_lower
-        < get_default_max_visit_window_gap()
+        and appointment.visit.max_window_gap_to_lower < get_default_max_visit_window_gap()
     ):
         max_gap = appointment.visit.max_window_gap_to_lower
     else:
@@ -594,7 +574,7 @@ def appt_datetime_in_next_window_adjusted_for_gap(
     in_window = False
     gap_days = get_window_gap_days(appointment)
     max_gap = get_max_window_gap_to_lower(appointment)
-    gap_days = max_gap if gap_days > max_gap else gap_days
+    gap_days = min(gap_days, max_gap)
     if gap_days > 0:
         next_lower_datetime = (
             appointment.next.timepoint_datetime
@@ -642,7 +622,7 @@ def get_appointment_by_datetime(
             raise_on_appt_datetime_not_in_window(
                 appointment, appt_datetime=suggested_appt_datetime
             )
-        except AppointmentWindowError:
+        except AppointmentWindowError as e:
             in_gap = appt_datetime_in_gap(appointment, suggested_appt_datetime)
             in_next_window_adjusted = appt_datetime_in_next_window_adjusted_for_gap(
                 appointment, suggested_appt_datetime
@@ -654,23 +634,22 @@ def get_appointment_by_datetime(
                 raise AppointmentDateWindowPeriodGapError(
                     f"Date falls in a `window period gap` between {appointment.visit_code} "
                     f"and {appointment.next.visit_code}. Got {dt}."
-                )
-            elif (
+                ) from e
+            if (
                 in_gap
                 and in_next_window_adjusted
                 and appointment.next.visit.add_window_gap_to_lower
             ):
                 appointment = appointment.next
                 break
-            elif (
+            if (
                 in_gap
                 and not in_next_window_adjusted
                 and appointment.next.visit.add_window_gap_to_lower
             ):
                 appointment = None
                 break
-            else:
-                appointment = appointment.next
+            appointment = appointment.next
         else:
             break
     return appointment
@@ -690,27 +669,26 @@ def reset_appointment(appointment: Appointment, **kwargs):
         raise AppointmentAlreadyStarted(
             f"Unable to reset. Appointment already started. Got {appointment}."
         )
-    else:
-        defaults = dict(
-            appt_status=appointment._meta.get_field("appt_status").default,
-            appt_timing=appointment._meta.get_field("appt_timing").default,
-            appt_type=None,
-            appt_type_other=None,
-            appt_datetime=appointment.timepoint_datetime,
-            comment="",
-        )
-        defaults.update(**kwargs)
-        for k, v in defaults.items():
+    defaults = dict(
+        appt_status=appointment._meta.get_field("appt_status").default,
+        appt_timing=appointment._meta.get_field("appt_timing").default,
+        appt_type=None,
+        appt_type_other="",
+        appt_datetime=appointment.timepoint_datetime,
+        comment="",
+    )
+    defaults.update(**kwargs)
+    for k, v in defaults.items():
+        try:
+            related_model = get_model_from_relation(appointment._meta.get_field(k))
+        except NotRelationField:
+            setattr(appointment, k, v)
+        else:
             try:
-                related_model = get_model_from_relation(appointment._meta.get_field(k))
-            except NotRelationField:
-                setattr(appointment, k, v)
-            else:
-                try:
-                    setattr(appointment, k, related_model.objects.get(name=v))
-                except ObjectDoesNotExist:
-                    setattr(appointment, k, None)
-        appointment.save_base(update_fields=[*defaults.keys()])
+                setattr(appointment, k, related_model.objects.get(name=v))
+            except ObjectDoesNotExist:
+                setattr(appointment, k, None)
+    appointment.save_base(update_fields=[*defaults.keys()])
 
 
 def skip_appointment(appointment: Appointment, comment: str | None = None):
@@ -721,14 +699,13 @@ def skip_appointment(appointment: Appointment, comment: str | None = None):
         raise AppointmentAlreadyStarted(
             f"Unable to skip. Appointment already started. Got {appointment}."
         )
-    else:
-        reset_appointment(
-            appointment,
-            appt_status=SKIPPED_APPT,
-            appt_timing=NOT_APPLICABLE,
-            appt_type=NOT_APPLICABLE,
-            comment=comment,
-        )
+    reset_appointment(
+        appointment,
+        appt_status=SKIPPED_APPT,
+        appt_timing=NOT_APPLICABLE,
+        appt_type=NOT_APPLICABLE,
+        comment=comment or "",
+    )
 
 
 def get_unscheduled_appointment_url(appointment: Appointment = None) -> str:
@@ -744,11 +721,6 @@ def get_unscheduled_appointment_url(appointment: Appointment = None) -> str:
         visit_code_sequence=appointment.visit_code_sequence + 1,
         timepoint=appointment.timepoint,
     )
-    # if appointment := (
-    #     appointment.__class__.objects.filter(visit_code_sequence__gt=0, **kwargs)
-    #     .order_by("visit_code_sequence")
-    #     .last()
-    # ):
     kwargs.update(visit_code_sequence=str(appointment.visit_code_sequence + 1))
     kwargs.update(redirect_url=dashboard_url)
     return reverse(unscheduled_appointment_url_name, kwargs=kwargs)
@@ -759,27 +731,22 @@ def update_appt_status_for_timepoint(related_visit: RelatedVisitModel) -> None:
     if related_visit.appointment.appt_status == COMPLETE_APPT:
         if (
             related_visit.metadata[CRF].filter(entry_status=REQUIRED).exists()
-            or related_visit.metadata[REQUISITION]
-            .filter(entry_status=REQUIRED)
-            .exists()
+            or related_visit.metadata[REQUISITION].filter(entry_status=REQUIRED).exists()
         ):
             related_visit.appointment.appt_status = INCOMPLETE_APPT
             related_visit.appointment.save_base(update_fields=["appt_status"])
-    elif related_visit.appointment.appt_status == INCOMPLETE_APPT:
-        if (
-            not related_visit.metadata[CRF].filter(entry_status=REQUIRED).exists()
-            and not related_visit.metadata[REQUISITION]
-            .filter(entry_status=REQUIRED)
-            .exists()
-        ):
-            related_visit.appointment.appt_status = COMPLETE_APPT
-            related_visit.appointment.save_base(update_fields=["appt_status"])
+    elif related_visit.appointment.appt_status == INCOMPLETE_APPT and (
+        not related_visit.metadata[CRF].filter(entry_status=REQUIRED).exists()
+        and not related_visit.metadata[REQUISITION].filter(entry_status=REQUIRED).exists()
+    ):
+        related_visit.appointment.appt_status = COMPLETE_APPT
+        related_visit.appointment.save_base(update_fields=["appt_status"])
 
 
 def refresh_appointments(
-    subject_identifier: str = None,
-    visit_schedule_name: str = None,
-    schedule_name: str = None,
+    subject_identifier: str | None = None,
+    visit_schedule_name: str | None = None,
+    schedule_name: str | None = None,
     request: WSGIRequest | None = None,
     warn_only: bool | None = None,
 ) -> tuple[str, str]:
@@ -840,7 +807,7 @@ def validate_date_is_on_clinic_day(
             raise raise_validation_error(
                 {"appt_date": "Cannot be equal to the report datetime"}, INVALID_ERROR
             )
-        elif appt_date <= report_date:
+        if appt_date <= report_date:
             raise raise_validation_error(
                 {"appt_date": "Cannot be before the report datetime"}, INVALID_ERROR
             )
@@ -854,9 +821,7 @@ def validate_date_is_on_clinic_day(
                         "mon": day_abbr[calendar.MONDAY],
                         "fri": day_abbr[calendar.FRIDAY],
                         "day": day_abbr[
-                            calendar.weekday(
-                                appt_date.year, appt_date.month, appt_date.day
-                            )
+                            calendar.weekday(appt_date.year, appt_date.month, appt_date.day)
                         ],
                     }
                 },
@@ -867,6 +832,8 @@ def validate_date_is_on_clinic_day(
             and calendar.weekday(appt_date.year, appt_date.month, appt_date.day)
             not in clinic_days
         ):
+
+            days_str = [day_abbr[d] for d in clinic_days]
             days_str = []
             for d in clinic_days:
                 days_str.append(day_abbr[d])
