@@ -1,7 +1,4 @@
-from typing import Tuple
-
-
 class DocumentStatusModelAdminMixin:
-    def get_readonly_fields(self, request, obj=None) -> Tuple[str, ...]:
+    def get_readonly_fields(self, request, obj=None) -> tuple[str, ...]:
         readonly_fields = super().get_readonly_fields(request, obj=obj)
         return tuple(set(readonly_fields + ("document_status",)))
