@@ -2,7 +2,7 @@ from django.db import models
 
 from edc_reportable.units import PLUS
 
-from ..model_mixin_factory import reportable_result_model_mixin_factory
+from ..model_mixin_factories import reportable_result_model_mixin_factory
 
 
 class ProteinuriaModelMixin(
