@@ -1,13 +1,11 @@
-from typing import Optional
-
 from .model_notification import ModelNotification
 
 
 class GradedEventNotification(ModelNotification):
-    grade: Optional[int] = None
-    model: Optional[str] = None
-    create_fields = ["ae_grade"]
-    update_fields = ["ae_grade"]
+    grade: int | None = None
+    model: str | None = None
+    create_fields: tuple[str] = ("ae_grade",)
+    update_fields: tuple[str] = ("ae_grade",)
 
     def field_value_condition_on_create(self, field, current_value):
         return str(current_value) == str(self.grade)
