@@ -3,9 +3,9 @@ from .model_notification import ModelNotification
 
 
 class UpdatedModelNotification(ModelNotification):
-    model_operations = [UPDATE]
+    model_operations = (UPDATE,)
 
-    update_fields = ["modified"]
+    update_fields = ("modified",)
 
     email_subject_template = (
         "*UPDATE* {test_subject_line}{protocol_name}: "
