@@ -8,9 +8,7 @@ register = template.Library()
 
 
 @register.inclusion_tag("edc_offstudy/visit_schedule_row.html")
-def offstudy_visit_schedule_row(
-    subject_identifier, visit_schedule, subject_dashboard_url
-):
+def offstudy_visit_schedule_row(subject_identifier, visit_schedule, subject_dashboard_url):
     context = {}
     offstudy_model = visit_schedule.offstudy_model
     offstudy_model_cls = django_apps.get_model(offstudy_model)
@@ -21,9 +19,7 @@ def offstudy_visit_schedule_row(
     else:
         options = dict(subject_identifier=subject_identifier)
         query = unquote(urlencode(options))
-        href = (
-            f"{obj.get_absolute_url()}?next={subject_dashboard_url},subject_identifier"
-        )
+        href = f"{obj.get_absolute_url()}?next={subject_dashboard_url},subject_identifier"
         href = "&".join([href, query])
         context = dict(
             offstudy_datetime=obj.offstudy_datetime,
