@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from pathlib import Path
 from typing import TYPE_CHECKING
 
 from django.core.management.color import color_style
@@ -24,11 +25,12 @@ class CsvModelExporter:
         queryset: QuerySet | None = None,
         decrypt: bool | None = None,
         sort_by: list | tuple | str | None = None,
-        export_folder: str | None = None,
+        export_folder: Path | None = None,
         site_ids: list[int] | None = None,
         **kwargs,
     ):
         self.model = model or queryset.model._meta.label_lower
+        self.export_folder = export_folder
         self.df_maker = self.df_maker_cls(
             model=model,
             queryset=queryset,
@@ -45,8 +47,10 @@ class CsvModelExporter:
 
     def to_csv(self):
         dataframe = self.df_maker.dataframe
-        return self.csv_exporter.to_csv(dataframe=dataframe)
+        return self.csv_exporter.to_csv(dataframe=dataframe, export_folder=self.export_folder)
 
     def to_stata(self):
         dataframe = self.df_maker.dataframe
-        return self.csv_exporter.to_stata(dataframe=dataframe)
+        return self.csv_exporter.to_stata(
+            dataframe=dataframe, export_folder=self.export_folder
+        )
