@@ -13,8 +13,6 @@ def print_stock_report_action(modeladmin, request, queryset):
     if queryset.count() > 1:
         session_uuid = str(uuid4())
         request.session[session_uuid] = list(queryset.values_list("pk", flat=True))
-        url = reverse(
-            "edc_pharmacy:stock_report", kwargs={"session_uuid": session_uuid}
-        )
+        url = reverse("edc_pharmacy:stock_report", kwargs={"session_uuid": session_uuid})
         return HttpResponseRedirect(url)
     return None
