@@ -23,12 +23,12 @@ class ProtocolIncident(
     objects = ActionIdentifierModelManager()
 
     def natural_key(self):
-        return (self.action_identifier,)  # noqa
+        return (self.action_identifier,)
 
     class Meta(ProtocolIncidentModelMixin.Meta, BaseUuidModel.Meta):
         indexes = (
-            ProtocolIncidentModelMixin.Meta.indexes
-            + NonUniqueSubjectIdentifierFieldMixin.Meta.indexes
-            + ActionModelMixin.Meta.indexes
-            + BaseUuidModel.Meta.indexes
+            *ProtocolIncidentModelMixin.Meta.indexes,
+            *NonUniqueSubjectIdentifierFieldMixin.Meta.indexes,
+            *ActionModelMixin.Meta.indexes,
+            *BaseUuidModel.Meta.indexes,
         )
