@@ -5,7 +5,7 @@ from .model_mixins import SubjectRefusalModelMixin
 
 
 def get_subject_refusal_model() -> str:
-    return getattr(settings, "SUBJECT_REFUSAL_MODEL")
+    return settings.SUBJECT_REFUSAL_MODEL
 
 
 def get_subject_refusal_model_cls() -> SubjectRefusalModelMixin:
