@@ -1,20 +1,18 @@
-from typing import Optional
-
 from dateutil.relativedelta import relativedelta
+from django.utils import timezone
 from django.utils.timezone import localtime
 
 from edc_reportable.age_evaluator import AgeEvaluator as ReportableAgeEvaluator
 from edc_reportable.exceptions import ValueBoundryError
-from edc_utils.date import get_utcnow
 
 
 class AgeEvaluator(ReportableAgeEvaluator):
     def __init__(self, **kwargs) -> None:
-        self.reasons_ineligible: Optional[str] = None
+        self.reasons_ineligible: str = ""
         super().__init__(**kwargs)
 
-    def eligible(self, age: Optional[int] = None) -> bool:
-        self.reasons_ineligible = None
+    def eligible(self, age: int | None = None) -> bool:
+        self.reasons_ineligible = ""
         eligible = False
         if age:
             try:
@@ -28,10 +26,10 @@ class AgeEvaluator(ReportableAgeEvaluator):
         return eligible
 
     def in_bounds_or_raise(self, age: int = None, **kwargs):
-        self.reasons_ineligible = None
-        dob = localtime(get_utcnow() - relativedelta(years=age)).date()
+        self.reasons_ineligible = ""
+        dob = localtime(timezone.now() - relativedelta(years=age)).date()
         age_units = "years"
-        report_datetime = localtime(get_utcnow())
+        report_datetime = localtime(timezone.now())
         return super().in_bounds_or_raise(
             dob=dob, report_datetime=report_datetime, age_units=age_units
         )
