@@ -34,9 +34,7 @@ class AlreadyConsentedFormMixin:
             kwargs={"subject_identifier": self.instance.subject_identifier},
         )
 
-    def already_consented_validation_message(
-        self, cleaned_data: dict | None = None
-    ) -> str:
+    def already_consented_validation_message(self, cleaned_data: dict | None = None) -> str:
         return format_html(
             'Not allowed. Subject has already consented. See subject <A href="{}">{}</A>',
             self.already_consented_validation_url(cleaned_data),
