@@ -1,13 +1,14 @@
 from __future__ import annotations
 
 from collections import namedtuple
-from typing import TYPE_CHECKING, Type, TypeVar
+from typing import TYPE_CHECKING, TypeVar
 
 from dateutil.relativedelta import relativedelta
 from django import template
 from django.apps import apps as django_apps
 from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
 from django.urls import reverse
+from django.utils import timezone
 
 from edc_appointment.constants import (
     CANCELLED_APPT,
@@ -26,7 +27,6 @@ from edc_appointment.view_utils import AppointmentButton
 from edc_auth.constants import AUDITOR_ROLE
 from edc_metadata import KEYED, REQUIRED
 from edc_metadata.metadata_helper import MetadataHelper
-from edc_utils import get_utcnow
 from edc_view_utils import PrnButton, render_history_and_query_buttons
 from edc_visit_tracking.view_utils import RelatedVisitButton
 
@@ -56,16 +56,16 @@ if TYPE_CHECKING:
 
 __all__ = [
     "appointment_in_progress",
-    "render_appointment_status_icon",
     "print_requisition_popover",
-    "render_prn_button",
     "render_appointment_button",
+    "render_appointment_status_icon",
     "render_crf_button_group",
-    "render_gotoforms_button",
-    "requisition_panel_actions",
     "render_crf_totals",
+    "render_gotoforms_button",
+    "render_prn_button",
     "render_subject_consent_dashboard_button",
     "render_unscheduled_appointment_button",
+    "requisition_panel_actions",
 ]
 
 register = template.Library()
@@ -171,14 +171,12 @@ def render_crf_totals(appointment: Appointment = None) -> dict[str, bool | int]:
         skipped = True
     elif (
         appointment.appt_status == NEW_APPT
-        and appointment.appt_datetime.date() < get_utcnow().date()
+        and appointment.appt_datetime.date() < timezone.now().date()
     ):
         overdue = True
     else:
         crf_keyed = helper.get_crf_metadata_by(entry_status=KEYED).count()
-        requisition_keyed = helper.get_requisition_metadata_by(
-            entry_status=KEYED
-        ).count()
+        requisition_keyed = helper.get_requisition_metadata_by(entry_status=KEYED).count()
         crf_total = helper.get_crf_metadata_by(entry_status=[REQUIRED, KEYED]).count()
         requisition_total = helper.get_requisition_metadata_by(
             entry_status=[REQUIRED, KEYED]
@@ -304,7 +302,7 @@ def render_related_visit_button(context, appointment: Appointment = None):
     # from model_wrapper
     appointment = getattr(appointment, "object", appointment)
     related_visit: VisitModel = appointment.related_visit
-    related_visit_model_cls: Type[VisitModel] = appointment.related_visit_model_cls()
+    related_visit_model_cls: type[VisitModel] = appointment.related_visit_model_cls()
     btn = RelatedVisitButton(
         model_obj=related_visit,
         model_cls=related_visit_model_cls,
@@ -324,7 +322,7 @@ def render_gotoforms_button(context, appointment: Appointment = None):
     # from model_wrapper
     appointment: Appointment = getattr(appointment, "object", appointment)
     related_visit: VisitModel = appointment.related_visit
-    related_visit_model_cls: Type[VisitModel] = appointment.related_visit_model_cls()
+    related_visit_model_cls: type[VisitModel] = appointment.related_visit_model_cls()
     btn = GotToFormsButton(
         model_obj=related_visit,
         model_cls=related_visit_model_cls,
@@ -426,8 +424,7 @@ def render_unscheduled_appointment_button(
     ):
         show_button = True
         anchor_id = (
-            f"unscheduled_appt_btn_{appointment.visit_code}_"
-            f"{appointment.visit_code_sequence}"
+            f"unscheduled_appt_btn_{appointment.visit_code}_{appointment.visit_code_sequence}"
         )
         if view_appointment and appointment.site.id == context["request"].site.id:
             url = get_unscheduled_appointment_url(appointment)
@@ -470,9 +467,7 @@ def render_screening_button(context, subject_screening) -> dict:
 def render_subject_schedule_button(
     subject_dashboard_url: str, subject_identifier: str
 ) -> dict:
-    url = reverse(
-        subject_dashboard_url, kwargs=dict(subject_identifier=subject_identifier)
-    )
+    url = reverse(subject_dashboard_url, kwargs=dict(subject_identifier=subject_identifier))
     return dict(url=url, subject_identifier=subject_identifier)
 
 
@@ -486,9 +481,9 @@ def render_refresh_appointments_button(
     visit_schedule_name: str = None,
     schedule_name: str = None,
 ) -> dict:
-    if context["request"].user.userprofile.is_multisite_viewer:
-        url = None
-    elif context["request"].user.userprofile.roles.filter(name=AUDITOR_ROLE):
+    if context["request"].user.userprofile.is_multisite_viewer or context[
+        "request"
+    ].user.userprofile.roles.filter(name=AUDITOR_ROLE):
         url = None
     else:
         url = reverse(
@@ -512,11 +507,11 @@ def render_refresh_data_collection_schedule_button(
     visit_schedule_name: str = None,
     schedule_name: str = None,
 ) -> dict:
-    if context["request"].user.userprofile.is_multisite_viewer:
-        url = None
-    elif context["request"].user.userprofile.roles.filter(name=AUDITOR_ROLE):
-        url = None
-    elif not related_visit_id:
+    if (
+        context["request"].user.userprofile.is_multisite_viewer
+        or context["request"].user.userprofile.roles.filter(name=AUDITOR_ROLE)
+        or not related_visit_id
+    ):
         url = None
     else:
         url = reverse(
